
RELEASE_VERSION='0.3.595748348'
BUILD_DATE='Mon Jul 25 07:46:19 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-0cfqrh 5.4.181-99.354.amzn2.x86_64 #1 SMP Wed Mar 2 18:50:46 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2764023926'
GIT_COMMIT_SHA='ac1a8b85c5a134fe5088d89efb9d271998ae8eba'
GIT_BRANCH='main'
